@@ -9,7 +9,7 @@ def main():
     '''
     Main method
     '''
-    parser = argparse.ArgumentParser("pydanfossair")
+    parser = argparse.ArgumentParser("pyeloverblik")
     parser.add_argument("--log", action="store", required=False)
     parser.add_argument("--refresh-token", action="store", required=True)
     parser.add_argument('--metering-point', action='store', required=True)
@@ -35,7 +35,7 @@ def _configureLogging(args):
     if args.log:
         numeric_level = getattr(logging, args.log.upper(), None)
         if not isinstance(numeric_level, int):
-            raise ValueError('Invalid log level: %s' % loglevel)
+            raise ValueError('Invalid log level: %s' % args.log)
         
         logging.basicConfig(level=numeric_level)
 
